@@ -23,8 +23,9 @@ describe 'tripleo::profile::base::aodh' do
       it 'should do nothing' do
         is_expected.to contain_class('tripleo::profile::base::aodh')
         is_expected.to_not contain_class('aodh')
-        is_expected.to_not contain_class('aodh::auth')
+        is_expected.to_not contain_class('aodh::service_credentials')
         is_expected.to_not contain_class('aodh::config')
+        is_expected.to_not contain_class('aodh::db')
         is_expected.to_not contain_class('aodh::db::sync')
       end
     end
@@ -42,8 +43,9 @@ describe 'tripleo::profile::base::aodh' do
         is_expected.to contain_class('aodh').with(
           :default_transport_url => 'rabbit://aodh:foo@127.0.0.1:5672/?ssl=0'
         )
-        is_expected.to contain_class('aodh::auth')
+        is_expected.to contain_class('aodh::service_credentials')
         is_expected.to contain_class('aodh::config')
+        is_expected.to contain_class('aodh::db')
         is_expected.to contain_class('aodh::db::sync')
       end
     end
@@ -56,8 +58,9 @@ describe 'tripleo::profile::base::aodh' do
 
       it 'should not trigger any configuration' do
         is_expected.to_not contain_class('aodh')
-        is_expected.to_not contain_class('aodh::auth')
+        is_expected.to_not contain_class('aodh::service_credentials')
         is_expected.to_not contain_class('aodh::config')
+        is_expected.to_not contain_class('aodh::db')
         is_expected.to_not contain_class('aodh::db::sync')
       end
     end
@@ -75,8 +78,9 @@ describe 'tripleo::profile::base::aodh' do
         is_expected.to contain_class('aodh').with(
           :default_transport_url => 'rabbit://aodh:foo@127.0.0.1:5672/?ssl=0'
         )
-        is_expected.to contain_class('aodh::auth')
+        is_expected.to contain_class('aodh::service_credentials')
         is_expected.to contain_class('aodh::config')
+        is_expected.to contain_class('aodh::db')
         is_expected.to contain_class('aodh::db::sync')
       end
     end
