@@ -34,6 +34,7 @@ describe 'tripleo::profile::base::barbican::api' do
         is_expected.to contain_class('tripleo::profile::base::barbican')
         is_expected.to_not contain_class('barbican::api')
         is_expected.to_not contain_class('barbican::api::logging')
+        is_expected.to_not contain_class('barbican::healthcheck')
         is_expected.to_not contain_class('barbican::keystone::notification')
         is_expected.to_not contain_class('barbican::quota')
         is_expected.to_not contain_class('barbican::wsgi::apache')
@@ -52,6 +53,7 @@ describe 'tripleo::profile::base::barbican::api' do
         is_expected.to contain_class('barbican::db::sync')
         is_expected.to contain_class('barbican::api')
         is_expected.to contain_class('barbican::api::logging')
+        is_expected.to contain_class('barbican::healthcheck')
         is_expected.to contain_class('barbican::keystone::notification')
         is_expected.to contain_class('barbican::quota')
         is_expected.to contain_class('barbican::wsgi::apache')
@@ -70,6 +72,7 @@ describe 'tripleo::profile::base::barbican::api' do
         is_expected.to_not contain_class('barbican::db::sync')
         is_expected.to_not contain_class('barbican::api')
         is_expected.to_not contain_class('barbican::api::logging')
+        is_expected.to_not contain_class('barbican::healthcheck')
         is_expected.to_not contain_class('barbican::keystone::notification')
         is_expected.to_not contain_class('barbican::quota')
         is_expected.to_not contain_class('barbican::wsgi::apache')
@@ -87,6 +90,7 @@ describe 'tripleo::profile::base::barbican::api' do
         #is_expected.to_not contain_class('barbican::db::sync')
         is_expected.to contain_class('barbican::api')
         is_expected.to contain_class('barbican::api::logging')
+        is_expected.to contain_class('barbican::healthcheck')
         is_expected.to contain_class('barbican::keystone::notification')
         is_expected.to contain_class('barbican::quota')
         is_expected.to contain_class('barbican::wsgi::apache')
