@@ -24,6 +24,7 @@ describe 'tripleo::profile::base::barbican' do
         is_expected.to contain_class('tripleo::profile::base::barbican')
         is_expected.to_not contain_class('barbican')
         is_expected.to_not contain_class('barbican::config')
+        is_expected.to_not contain_class('barbican::db')
       end
     end
 
@@ -38,6 +39,7 @@ describe 'tripleo::profile::base::barbican' do
         )
         is_expected.to contain_class('barbican')
         is_expected.to contain_class('barbican::config')
+        is_expected.to contain_class('barbican::db')
       end
     end
   end
