@@ -24,10 +24,13 @@ describe 'tripleo::profile::base::cinder' do
         is_expected.to contain_class('tripleo::profile::base::cinder')
         is_expected.to_not contain_class('cinder')
         is_expected.to_not contain_class('cinder::config')
+        is_expected.to_not contain_class('cinder::db')
         is_expected.to_not contain_class('cinder::glance')
         is_expected.to_not contain_class('cinder::nova')
         is_expected.to_not contain_class('cinder::logging')
         is_expected.to_not contain_class('cinder::keystone::service_user')
+        is_expected.to_not contain_class('cinder::key_manager')
+        is_expected.to_not contain_class('cinder::key_manager::barbican')
         is_expected.to_not contain_class('cinder:::cron::db_purge')
       end
     end
@@ -52,10 +55,13 @@ describe 'tripleo::profile::base::cinder' do
           :notification_transport_url => 'rabbit://cinder2:baa@192.168.0.2:5678/?ssl=0'
         )
         is_expected.to contain_class('cinder::config')
+        is_expected.to contain_class('cinder::db')
         is_expected.to contain_class('cinder::glance')
         is_expected.to contain_class('cinder::nova')
         is_expected.to contain_class('cinder::logging')
         is_expected.to contain_class('cinder::keystone::service_user')
+        is_expected.to contain_class('cinder::key_manager')
+        is_expected.to contain_class('cinder::key_manager::barbican')
         is_expected.to_not contain_class('cinder::cron::db_purge')
       end
     end
@@ -69,10 +75,13 @@ describe 'tripleo::profile::base::cinder' do
       it 'should not trigger any configuration' do
         is_expected.to_not contain_class('cinder')
         is_expected.to_not contain_class('cinder::config')
+        is_expected.to_not contain_class('cinder::db')
         is_expected.to_not contain_class('cinder::glance')
         is_expected.to_not contain_class('cinder::nova')
         is_expected.to_not contain_class('cinder::logging')
         is_expected.to_not contain_class('cinder::keystone::service_user')
+        is_expected.to_not contain_class('cinder::key_manager')
+        is_expected.to_not contain_class('cinder::key_manager::barbican')
         is_expected.to_not contain_class('cinder:::cron::db_purge')
       end
     end
@@ -97,10 +106,13 @@ describe 'tripleo::profile::base::cinder' do
           :notification_transport_url => 'rabbit://cinder2:baa@192.168.0.2:5678/?ssl=0'
         )
         is_expected.to contain_class('cinder::config')
+        is_expected.to contain_class('cinder::db')
         is_expected.to contain_class('cinder::glance')
         is_expected.to contain_class('cinder::nova')
         is_expected.to contain_class('cinder::logging')
         is_expected.to contain_class('cinder::keystone::service_user')
+        is_expected.to contain_class('cinder::key_manager')
+        is_expected.to contain_class('cinder::key_manager::barbican')
         is_expected.to_not contain_class('cinder:::cron::db_purge')
       end
     end
@@ -119,10 +131,13 @@ describe 'tripleo::profile::base::cinder' do
           :default_transport_url => 'rabbit://cinder:foo@127.0.0.1:5672/?ssl=0'
         )
         is_expected.to contain_class('cinder::config')
+        is_expected.to contain_class('cinder::db')
         is_expected.to contain_class('cinder::glance')
         is_expected.to contain_class('cinder::nova')
         is_expected.to contain_class('cinder::logging')
         is_expected.to contain_class('cinder::keystone::service_user')
+        is_expected.to contain_class('cinder::key_manager')
+        is_expected.to contain_class('cinder::key_manager::barbican')
         is_expected.to contain_class('cinder::cron::db_purge')
       end
     end
@@ -142,10 +157,13 @@ describe 'tripleo::profile::base::cinder' do
           :default_transport_url => 'rabbit://cinder:foo@127.0.0.1:5672/?ssl=0'
         )
         is_expected.to contain_class('cinder::config')
+        is_expected.to contain_class('cinder::db')
         is_expected.to contain_class('cinder::glance')
         is_expected.to contain_class('cinder::nova')
         is_expected.to contain_class('cinder::logging')
         is_expected.to contain_class('cinder::keystone::service_user')
+        is_expected.to contain_class('cinder::key_manager')
+        is_expected.to contain_class('cinder::key_manager::barbican')
         is_expected.to_not contain_class('cinder::cron::db_purge')
       end
     end
