@@ -32,6 +32,8 @@ describe 'tripleo::profile::base::glance::api' do
         is_expected.to contain_class('tripleo::profile::base::glance::api')
         is_expected.to_not contain_class('glance')
         is_expected.to_not contain_class('glance::config')
+        is_expected.to_not contain_class('glance::healthcheck')
+        is_expected.to_not contain_class('glance::api::db')
         is_expected.to_not contain_class('glance::api::logging')
         is_expected.to_not contain_class('glance::api')
         is_expected.to_not contain_class('glance::key_manager')
@@ -61,6 +63,8 @@ describe 'tripleo::profile::base::glance::api' do
         is_expected.to contain_class('tripleo::profile::base::glance::api')
         is_expected.to contain_class('glance')
         is_expected.to contain_class('glance::config')
+        is_expected.to contain_class('glance::healthcheck')
+        is_expected.to contain_class('glance::api::db')
         is_expected.to contain_class('glance::api::logging')
         is_expected.to contain_class('glance::api')
         is_expected.to contain_class('glance::key_manager')
@@ -85,6 +89,8 @@ describe 'tripleo::profile::base::glance::api' do
         is_expected.to contain_class('tripleo::profile::base::glance::api')
         is_expected.to_not contain_class('glance')
         is_expected.to_not contain_class('glance::config')
+        is_expected.to_not contain_class('glance::healthcheck')
+        is_expected.to_not contain_class('glance::api::db')
         is_expected.to_not contain_class('glance::api::logging')
         is_expected.to_not contain_class('glance::api')
         is_expected.to_not contain_class('glance::key_manager')
@@ -114,6 +120,8 @@ describe 'tripleo::profile::base::glance::api' do
         is_expected.to contain_class('tripleo::profile::base::glance::api')
         is_expected.to contain_class('glance')
         is_expected.to contain_class('glance::config')
+        is_expected.to contain_class('glance::healthcheck')
+        is_expected.to contain_class('glance::api::db')
         is_expected.to contain_class('glance::api::logging')
         is_expected.to contain_class('glance::api').with(
           :enabled_backends => ['default_backend:swift'],
