@@ -30,10 +30,9 @@ describe 'tripleo::profile::base::gnocchi' do
 
       it {
         is_expected.to_not contain_class('gnocchi')
-        is_expected.to_not contain_class('gnocchi::db')
         is_expected.to_not contain_class('gnocchi::config')
         is_expected.to_not contain_class('gnocchi::cors')
-        is_expected.to_not contain_class('gnocchi::client')
+        is_expected.to_not contain_class('gnocchi::db')
         is_expected.to_not contain_class('gnocchi::logging')
       }
     end
@@ -50,10 +49,9 @@ describe 'tripleo::profile::base::gnocchi' do
         is_expected.to contain_class('gnocchi').with(
           :coordination_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
-        is_expected.to contain_class('gnocchi::db')
         is_expected.to contain_class('gnocchi::config')
         is_expected.to contain_class('gnocchi::cors')
-        is_expected.to contain_class('gnocchi::client')
+        is_expected.to contain_class('gnocchi::db')
         is_expected.to contain_class('gnocchi::logging')
       }
     end
@@ -66,10 +64,9 @@ describe 'tripleo::profile::base::gnocchi' do
 
       it {
         is_expected.to_not contain_class('gnocchi')
-        is_expected.to_not contain_class('gnocchi::db')
         is_expected.to_not contain_class('gnocchi::config')
         is_expected.to_not contain_class('gnocchi::cors')
-        is_expected.to_not contain_class('gnocchi::client')
+        is_expected.to_not contain_class('gnocchi::db')
         is_expected.to_not contain_class('gnocchi::logging')
       }
     end
@@ -85,10 +82,9 @@ describe 'tripleo::profile::base::gnocchi' do
         is_expected.to contain_class('gnocchi').with(
           :coordination_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
-        is_expected.to contain_class('gnocchi::db')
         is_expected.to contain_class('gnocchi::config')
         is_expected.to contain_class('gnocchi::cors')
-        is_expected.to contain_class('gnocchi::client')
+        is_expected.to contain_class('gnocchi::db')
         is_expected.to contain_class('gnocchi::logging')
       }
     end
