@@ -36,6 +36,7 @@ eos
         is_expected.to_not contain_class('heat')
         is_expected.to_not contain_class('heat::config')
         is_expected.to_not contain_class('heat::cors')
+        is_expected.to_not contain_class('heat::db')
         is_expected.to_not contain_class('heat::logging')
         is_expected.to_not contain_class('heat::cache')
         is_expected.to_not contain_class('heat::cron::purge_deleted')
@@ -70,6 +71,7 @@ eos
         )
         is_expected.to contain_class('heat::config')
         is_expected.to contain_class('heat::cors')
+        is_expected.to contain_class('heat::db')
         is_expected.to contain_class('heat::logging')
         is_expected.to contain_class('heat::cache').with(
           :memcache_servers => ['127.0.0.1:11211']
@@ -106,6 +108,7 @@ eos
         )
         is_expected.to contain_class('heat::config')
         is_expected.to contain_class('heat::cors')
+        is_expected.to contain_class('heat::db')
         is_expected.to contain_class('heat::logging')
         is_expected.to contain_class('heat::cache')
         is_expected.to contain_class('heat::cache').with(
@@ -145,6 +148,7 @@ eos
         )
         is_expected.to contain_class('heat::config')
         is_expected.to contain_class('heat::cors')
+        is_expected.to contain_class('heat::db')
         is_expected.to contain_class('heat::logging')
         is_expected.to contain_class('heat::cache').with(
           :memcache_servers => ['[::1]:11211']
