@@ -43,7 +43,9 @@ describe 'tripleo::profile::base::keystone' do
       it 'should do nothing' do
         is_expected.to contain_class('tripleo::profile::base::keystone')
         is_expected.to_not contain_class('keystone')
+        is_expected.to_not contain_class('keystone::healthcheck')
         is_expected.to_not contain_class('keystone::config')
+        is_expected.to_not contain_class('keystone::db')
         is_expected.to_not contain_class('keystone::logging')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
         is_expected.to_not contain_class('keystone::wsgi::apache')
@@ -68,7 +70,9 @@ describe 'tripleo::profile::base::keystone' do
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
           :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
         )
+        is_expected.to contain_class('keystone::healthcheck')
         is_expected.to contain_class('keystone::config')
+        is_expected.to contain_class('keystone::db')
         is_expected.to contain_class('keystone::logging')
         is_expected.to contain_class('tripleo::profile::base::apache')
         is_expected.to contain_class('keystone::wsgi::apache')
@@ -92,7 +96,9 @@ describe 'tripleo::profile::base::keystone' do
       it 'should not trigger any configuration' do
         is_expected.to contain_class('tripleo::profile::base::keystone')
         is_expected.to_not contain_class('keystone')
+        is_expected.to_not contain_class('keystone::healthcheck')
         is_expected.to_not contain_class('keystone::config')
+        is_expected.to_not contain_class('keystone::db')
         is_expected.to_not contain_class('keystone::logging')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
         is_expected.to_not contain_class('keystone::wsgi::apache')
@@ -117,7 +123,9 @@ describe 'tripleo::profile::base::keystone' do
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
           :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
         )
+        is_expected.to contain_class('keystone::healthcheck')
         is_expected.to contain_class('keystone::config')
+        is_expected.to contain_class('keystone::db')
         is_expected.to contain_class('keystone::logging')
         is_expected.to contain_class('tripleo::profile::base::apache')
         is_expected.to contain_class('keystone::wsgi::apache')
@@ -146,7 +154,9 @@ describe 'tripleo::profile::base::keystone' do
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
           :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
         )
+        is_expected.to contain_class('keystone::healthcheck')
         is_expected.to contain_class('keystone::config')
+        is_expected.to contain_class('keystone::db')
         is_expected.to contain_class('keystone::logging')
         is_expected.to contain_class('tripleo::profile::base::apache')
         is_expected.to contain_class('keystone::wsgi::apache')
