@@ -42,11 +42,13 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
+        is_expected.to_not contain_class('neutron::wsgi::apache')
         is_expected.to_not contain_class('neutron::server::notifications')
         is_expected.to_not contain_class('neutron::server::notifications::nova')
         is_expected.to_not contain_class('neutron::server::placement')
         is_expected.to_not contain_class('neutron::server')
         is_expected.to_not contain_class('neutron::db')
+        is_expected.to_not contain_class('neutron::healthcheck')
         is_expected.to_not contain_class('neutron::quota')
       end
     end
@@ -61,11 +63,13 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to contain_class('tripleo::profile::base::apache')
+        is_expected.to contain_class('neutron::wsgi::apache')
         is_expected.to_not contain_class('neutron::server::notifications')
         is_expected.to_not contain_class('neutron::server::notifications::nova')
         is_expected.to_not contain_class('neutron::server::placement')
         is_expected.to_not contain_class('neutron::server')
         is_expected.to_not contain_class('neutron::db')
+        is_expected.to_not contain_class('neutron::healthcheck')
         is_expected.to_not contain_class('neutron::quota')
       end
     end
@@ -80,11 +84,13 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
+        is_expected.to_not contain_class('neutron::wsgi::apache')
         is_expected.to_not contain_class('neutron::server::notifications')
         is_expected.to_not contain_class('neutron::server::notifications::nova')
         is_expected.to_not contain_class('neutron::server::placement')
         is_expected.to_not contain_class('neutron::server')
         is_expected.to_not contain_class('neutron::db')
+        is_expected.to_not contain_class('neutron::healthcheck')
         is_expected.to_not contain_class('neutron::quota')
       end
     end
@@ -99,6 +105,7 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to contain_class('tripleo::profile::base::apache')
+        is_expected.to contain_class('neutron::wsgi::apache')
         is_expected.to contain_class('neutron::server::notifications')
         is_expected.to contain_class('neutron::server::notifications::nova')
         is_expected.to contain_class('neutron::server::placement')
@@ -107,6 +114,7 @@ eos
           :l3_ha   => false,
         )
         is_expected.to contain_class('neutron::db')
+        is_expected.to contain_class('neutron::healthcheck')
         is_expected.to contain_class('neutron::quota')
       end
     end
@@ -121,11 +129,13 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to contain_class('tripleo::profile::base::apache')
+        is_expected.to contain_class('neutron::wsgi::apache')
         is_expected.to_not contain_class('neutron::server::notifications')
         is_expected.to_not contain_class('neutron::server::notifications::nova')
         is_expected.to_not contain_class('neutron::server::placement')
         is_expected.to_not contain_class('neutron::server')
         is_expected.to_not contain_class('neutron::db')
+        is_expected.to_not contain_class('neutron::healthcheck')
         is_expected.to_not contain_class('neutron::quota')
       end
     end
@@ -140,6 +150,7 @@ eos
         is_expected.to contain_class('tripleo::profile::base::neutron')
         is_expected.to contain_class('tripleo::profile::base::neutron::authtoken')
         is_expected.to contain_class('tripleo::profile::base::apache')
+        is_expected.to contain_class('neutron::wsgi::apache')
         is_expected.to contain_class('neutron::server::notifications')
         is_expected.to contain_class('neutron::server::notifications::nova')
         is_expected.to contain_class('neutron::server::placement')
@@ -148,6 +159,7 @@ eos
           :l3_ha   => false,
         )
         is_expected.to contain_class('neutron::db')
+        is_expected.to contain_class('neutron::healthcheck')
         is_expected.to contain_class('neutron::quota')
       end
     end
