@@ -105,6 +105,45 @@ describe 'tripleo::profile::base::qdr' do
         )
       end
     end
+
+    context 'with step 3 on node3 of multinode with ssl' do
+      before do
+        facts.merge!({
+          :hostname => 'node3.example.com',
+          :fqdn     => 'node3.example.com',
+        })
+        params.merge!({
+          :oslomsg_rpc_hosts => ['node1.example.com','node2.example.com','node3.example.com'],
+          :listener_require_ssl => 'yes',
+        })
+      end
+
+      it 'should set up interior listener with sslProfile and two connectors with sslProfile' do
+        is_expected.to contain_class('qdr').with(
+          # this should be true instead of 'yes', because 'yes' is deprecated,
+          # but until we have rspec-puppet >= 2.7.9 to get:
+          #
+          # https://github.com/rodjek/rspec-puppet/commit/5e6b5e40dd22c5db5a8c7d8f21597d8ba95b1ddc
+          #
+          # Then it will throw a FrozenError.  So just test with 'yes' instead.
+          :listener_require_ssl => 'yes',
+          :router_mode     => 'interior',
+          :extra_listeners => [{'sslProfile' => 'Router.node3.example.com',
+                                'host'       => '0.0.0.0',
+                                'port'       => '31460',
+                                'role'       => 'inter-router'}],
+          :connectors => [
+            {"sslProfile" => "Router.node3.example.com",
+             "host"       => "node1.example.com",
+             "role"       => "inter-router",
+             "port"       => "31460"},
+            {"sslProfile" => "Router.node3.example.com",
+             "host"       => "node2.example.com",
+             "role"       => "inter-router",
+             "port"       => "31460"}],
+        )
+      end
+    end
   end
 
   on_supported_os.each do |os, facts|
