@@ -24,12 +24,14 @@ describe 'tripleo::profile::base::neutron::wrappers::keepalived' do
 
   shared_examples_for 'tripleo::profile::base::neutron::wrappers::keepalived' do
 
-    context 'creates wrapper file' do
+    context 'creates wrapper file for docker' do
       let(:params) {
         {
           :keepalived_process_wrapper  => '/usr/local/bin/keepalived',
           :keepalived_image            => 'a_registry/some_container_name:some_tag',
-          :bind_socket                 => 'unix:///run/another/docker.sock'
+          :bind_socket                 => 'unix:///run/another/docker.sock',
+          :container_cli               => 'docker',
+          :debug                       => true,
         }
       }
 
@@ -43,6 +45,35 @@ describe 'tripleo::profile::base::neutron::wrappers::keepalived' do
         is_expected.to contain_file('/usr/local/bin/keepalived').with_content(
           /export DOCKER_HOST="unix:...run.another.docker.sock/
         )
+        is_expected.to contain_file('/usr/local/bin/keepalived').with_content(
+          /set -x/
+        )
+        is_expected.to contain_file('/usr/local/bin/keepalived').with_content(
+          /CMD="ip netns exec.*\/usr\/sbin\/keepalived -n -l -D/
+        )
+      end
+    end
+
+    context 'creates wrapper file for podman' do
+      let(:params) {
+        {
+          :keepalived_process_wrapper  => '/usr/local/bin/keepalived',
+          :keepalived_image            => 'a_registry/some_container_name:some_tag',
+          :container_cli               => 'podman',
+          :debug                       => false,
+        }
+      }
+
+      it 'should generate a wrapper file' do
+        is_expected.to contain_file('/usr/local/bin/keepalived').with(
+          :mode   => '0755'
+        )
+        is_expected.to contain_file('/usr/local/bin/keepalived').with_content(
+          /a_registry.some_container_name.some_tag/
+        )
+        is_expected.to contain_file('/usr/local/bin/keepalived').with_content(
+          /CMD='\/usr\/sbin\/keepalived -n -l -D'/
+        )
       end
     end
   end
